@@ -3,56 +3,32 @@ package DateTime::Format::Natural::Duration;
 use strict;
 use warnings;
 
-use DateTime::Format::Natural::Duration::Checks;
-use List::MoreUtils qw(all);
-
-our $VERSION = '0.05';
+our $VERSION = '0.01';
 
 sub _pre_duration
 {
     my $self = shift;
     my ($date_strings) = @_;
 
-    my $check_if = sub
-    {
-        my $sub   = shift;
-        my $class = join '::', (__PACKAGE__, 'Checks');
-        my $check = $class->can($sub) or die "$sub() not found in $class";
+    my $duration = $self->{data}->{duration};
 
-        return $check->($self->{data}->{duration}, $date_strings, @_);
-    };
-
-    my ($present, $extract, $adjust);
-
-    if ($check_if->('for', \$present)) {
-        @{$self->{insert}}{qw(datetime trace)} = do {
-            my $dt = $self->parse_datetime($present);
-            ($dt, $self->{traces}[0]);
-        };
+    if ($duration->{for}->($date_strings)) {
+        $self->{insert} = $self->parse_datetime('now');
     }
-    elsif ($check_if->('first_to_last', \$extract)) {
-        if (my ($complete) = $date_strings->[1] =~ $extract) {
+    elsif ($duration->{first_last}->($date_strings)) {
+        if (my ($complete) = $date_strings->[1] =~ /^\S+? \s+ (.*)/x) {
             $date_strings->[0] .= " $complete";
         }
     }
-    elsif ($check_if->('from_count_to_count', \$extract, \$adjust)) {
-        if (my ($complete) = $date_strings->[0] =~ $extract) {
-            $adjust->($date_strings, $complete);
-        }
-    }
 }
 
 sub _post_duration
 {
     my $self = shift;
-    my ($queue, $traces) = @_;
+    my ($queue) = @_;
 
-    my %assign = (
-        datetime => $queue,
-        trace    => $traces,
-    );
-    if (all { exists $self->{insert}{$_} } keys %assign) {
-        unshift @{$assign{$_}}, $self->{insert}{$_} foreach keys %assign;
+    if (exists $self->{insert}) {
+        unshift @$queue, $self->{insert};
     }
 }
 
@@ -61,7 +37,7 @@ sub _save_state
     my $self = shift;
     my %args = @_;
 
-    return if %{$self->{state}};
+    return if scalar keys %{$self->{state}};
 
     unless ($args{valid_expression}) {
         %{$self->{state}} = %args;
@@ -74,7 +50,7 @@ sub _restore_state
 
     my %state = %{$self->{state}};
 
-    if (%state) {
+    if (scalar keys %state) {
         $state{valid_expression}
           ? $self->_set_valid_exp
           : $self->_unset_valid_exp;
@@ -120,6 +96,6 @@ Steven Schubiger <schubiger@cpan.org>
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://dev.perl.org/licenses/>
+See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
